import 'package:fastyle_dart/fastyle_dart.dart';
import 'package:flutter/material.dart';

class FastTextField extends StatelessWidget {
  final String labelText;
  final String captionText;
  final String placeholderText;
  final String helperText;
  final bool isReadOnly;
  final ValueChanged<String> onValueChanged;
  final TextAlign textAlign;
  final TextEditingController textEditingController;
  final bool allowAutocorrect;

  FastTextField({
    Key key,
    @required this.labelText,
    this.captionText,
    this.placeholderText,
    this.helperText,
    this.onValueChanged,
    this.textAlign,
    this.textEditingController,
    bool isReadOnly = false,
    bool allowAutocorrect = false,
  })  : assert(labelText != null),
        this.isReadOnly = isReadOnly ?? false,
        this.allowAutocorrect = allowAutocorrect ?? false,
        super(key: key);

  @override
  Widget build(BuildContext context) {
    return FastFieldLayout(
      labelText: labelText,
      captionText: captionText,
      helperText: helperText,
      control: _buildControl(context),
    );
  }

  Widget _buildControl(BuildContext context) {
    return TextFormField(
      readOnly: isReadOnly,
      textAlign: textAlign ?? TextAlign.start,
      textInputAction: TextInputAction.done,
      autocorrect: allowAutocorrect,
      cursorColor: ThemeHelper.colors.getPrimaryColor(context),
      keyboardType: TextInputType.text,
      style: ThemeHelper.texts.getBodyTextStyle(context),
      decoration: InputDecoration(hintText: placeholderText),
      onChanged: onValueChanged,
      controller: textEditingController,
    );
  }
}
